/*
 * Roger Burton West <roger@firedrake.demon.co.uk>
 */
#include "inifile.h"

INIFile::INIFile(const char *fullfilename,const char *cmode)
{
  RATFile::RATFile(fullfilename,cmode);
}

INIFile::INIFile()
{
  RATFile::RATFile();
}

int INIFile::Open(const char *fullfilename,const char *cmode)
{
  regex_t tempreg;
  XString s;

  RATFile::Open(fullfilename,cmode);

  if (Status() == RAT_OK) {
    seccount=0;
    regcomp(&tempreg,"^ *\\[.*\\] *$",REG_NOSUB);
    s=FindR(&tempreg);
    while (s!="") {
      s=s.Mid(1);
      s=s.Left(s.Len()-1);
      secstart[seccount]=GetLivePos();
      section[seccount++]=s;
      s=FindNext();
    };
    Section((const char *)section[0]);
  }
  return Status();
}

bool INIFile::Section(const char *secname)
{
  int s;
  XString t;
  bool ok=false;;

  t=secname;
  for (s=0;s<seccount;s++) {
    if (+t == +section[s]) {
      secnum=s;
      SetLivePos(secstart[s]);
      ok=true;
    }
  }
  return ok;
}

XString INIFile::ReadKey(const char *key)
{
  regex_t tempreg;
  XString s,t;
  int k;

  s="(^ *\\[)|(^ *";
  s |= key;
  s |= " *=)";
  regcomp(&tempreg,(const char *)s,REG_NOSUB | REG_ICASE | REG_EXTENDED);

  SetLivePos(secstart[secnum]);
  t=FindR(&tempreg);
  t.Trim();
  if (t.Left(1)=="[" || t=="") {
    return "";
  }
  k=t.Find('=');
  k++;
  t=t.Mid(k);
  t.Trim();
  return t;
}

int INIFile::WriteKey(const char *key,const char *value)
{
  regex_t tempreg;
  XString s,t;

  s="(^ *\\[)|(^ *";
  s |= key;
  s |= " *=)";
  regcomp(&tempreg,(const char *)s,REG_NOSUB | REG_ICASE | REG_EXTENDED);

  SetLivePos(secstart[secnum]);
  t=FindR(&tempreg);
  if (t.Left(1)!="[" && t!="") {
    // delete old key=value
    SetPos(-1,RAT_CUR);
    DeleteLine();
  }
  SetLivePos(secstart[secnum]);
  SetPos(1,RAT_CUR);
  InsertLine();
  s=key;
  s |= "=";
  s |= value;
  Write((const char *)s);
  return 0;
}

XString INIFile::ReadSerial()
{
  XString v;

  v=Read();
  if (v.Left(1)=="[") {
    v="";
  }
  return v;
}

int INIFile::AddSerial(const char *serial)
{
  DelSerial(serial);
  SetLivePos(secstart[secnum]);
  InsertLine();
  Write(serial);
  return 0;
}

int INIFile::DelSerial(const char *serial)
{
  regex_t tempreg;
  XString s,t;

  s="(^ *\\[)|(^ *";
  s |= serial;
  s |= " *$)";
  regcomp(&tempreg,(const char *)s,REG_NOSUB | REG_ICASE | REG_EXTENDED);

  SetLivePos(secstart[secnum]);
  t=FindR(&tempreg);
  if (t.Left(1)!="[" && t!="") {
    // delete old key=value
    SetPos(-1,RAT_CUR);
    DeleteLine();
  }
  return 0;
}

int INIFile::Close()
{
  return RATFile::Close();
}

INIFile::~INIFile()
{
  Close();
}
