/*
 *
 * RATFILE - library for Random Access Text-files
 *
 * by Roger Burton West <roger@firedrake.demon.co.uk>
 *
 * Whatever it does, it's your fault
 *
 */

#ifndef _RATFILE_H
#define _RATFILE_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <sys/types.h>
#include <regex.h>
#include "xstring.h"

#define RAT_OK (0)
#define RAT_CLOSED (1)
#define RAT_ERR (2)

#define RAT_SET (0)
#define RAT_CUR (1)
#define RAT_END (2)

#define RATPOS long
#define MAX_LIVE 255

// structure is not guaranteed to contain these fields in future versions
/*
typedef struct RATLIVEPOS {
  RATPOS value;
};
*/

// feel free to change this for your system:
#define RATBUFSIZE 8192L

class RATFile {
private:
  int Copy(FILE *srchandle, FILE *desthandle, fpos_t bytes);
  XString filename;
  FILE *filehandle;
  FILE *workhandle;
  FILE *indexhandle;
  RATPOS ratpr;
  RATPOS ratpw;
  RATPOS end;
  RATPOS posit[MAX_LIVE];
  unsigned long livepointcount;
  int status;
  int searchdir;
  regex_t regholder;
  bool writeable;
  bool append;
  bool tempfile;
public:
  RATFile(const char *fullfilename,const char *cmode="r");
  RATFile();
  int Open(const char *fullfilename,const char *cmode="r");
  RATPOS GetPos();
  RATPOS SetPos(RATPOS posinput=0L,int mode=RAT_SET);
  RATPOS GetLength();
  RATPOS *GetLivePos();
  RATPOS SetLivePos(RATPOS *livepos);
  XString Read();
  XString Read(int length) {
    return Read().Left(length);
  }
  int Write(const char *datum);
  int InsertLine(int lines=1);
  int DeleteLine(int lines=1);
  XString Find(const char *datum);
  XString FindR(regex_t *datum);
  XString FindBack(const char *datum);
  XString FindBackR(regex_t *datum);
  XString FindNext();
  int Close();
  int Eof();
  int Status() {
    return status;
  }
  ~RATFile();
};

#endif
