/*
 * Read/write race-name data and gen.hst
 * part of the Host-Toolkit library
 */

#include <stdio.h>
#include "tkhost.h"
#include "tkh.h"
#include "tkiocomm.h"

RACENM * read_racenm(int rnum)
{
  FILE *handle;
  RACENM *str;

  handle=mkopen("race.nm",true,'r');
  if (!handle) return NULL;

  if (rnum>NUM_RACES || rnum<1) {
    fclose(handle);
    return NULL;
  }

  str=new RACENM;
  if (!str) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,30*(rnum-1),SEEK_SET);
  str->sFull=readXString(handle,30);

  fseek(handle,330+20*(rnum-1),SEEK_SET);
  str->sPlural=readXString(handle,20);

  fseek(handle,550+12*(rnum-1),SEEK_SET);
  str->sAdjective=readXString(handle,12);

  fclose(handle);
  return str;
}

RACENM *read_all_racenm()
{
  FILE *handle;
  RACENM *str;
  int vnum;

  handle=mkopen("race.nm",true,'r');
  if (!handle) return NULL;

  str=new RACENM [12];
  if (!str) {
    fclose(handle);
    return NULL;
  }

  for(vnum=1;vnum<=11;vnum++) {
    str[vnum].sFull=readXString(handle,30);
  }
  for(vnum=1;vnum<=11;vnum++) {
    str[vnum].sPlural=readXString(handle,20);
  }
  for(vnum=1;vnum<=11;vnum++) {
    str[vnum].sAdjective=readXString(handle,12);
  }

  fclose(handle);
  return str;
}

bool write_racenm(int rnum,RACENM *str)
{
  FILE *handle;
  bool v;

  handle=mkopen("race.nm",true,'w');
  if (!handle) return false;

  if (rnum>NUM_RACES || rnum<1) {
    fclose(handle);
    return false;
  }

  fseek(handle,30*(rnum-1),SEEK_SET);
  v=writeXString(handle,30,str->sFull);
  fseek(handle,330+20*(rnum-1),SEEK_SET);
  if (v) v=writeXString(handle,20,str->sPlural);
  fseek(handle,550+12*(rnum-1),SEEK_SET);
  if (v) v=writeXString(handle,12,str->sAdjective);

  fclose(handle);
  return v;
}

GENHOST *read_genhost()
{
  FILE *handle;
  GENHOST *str;
  XString pw1,pw2;
  unsigned char c;

  handle=mkopen("gen.hst",true,'r');
  if (!handle) return NULL;

  str=new GENHOST;
  if (!str) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,46,SEEK_SET);
  for (int i=1;i<=11;i++) {
    str->wPlaying[i]=readUB2(handle);
  }

  for (int i=1;i<11;i++) {
    fseek(handle,68+(i-1)*10,SEEK_SET);
    pw1=readXString(handle,10);
    fseek(handle,68+110+(i-1)*10,SEEK_SET);
    pw2=readXString(handle,10);
    for (int j=0;j<10;j++) {
      c=pw1.GetAt(j) - pw2.GetAt(9-j) + 32;
      if (c>127) c=0;
      str->sPassword[i] |= c;
    }
    if (str->sPassword[i]=="NOPASSWORD") str->sPassword[i]="";
  }

  fseek(handle,448,SEEK_SET);
  str->wLastNormalBuild=readUB2(handle);

  fclose(handle);
  return str;
}

bool write_genhost(GENHOST *str)
{
  FILE *handle;
  bool v=true;
  XString pw1="",pw2="3141592654";
  char c;

  handle=mkopen("gen.hst",true,'w');
  if (!handle) return false;


  fseek(handle,46,SEEK_SET);

  for (int i=1;i<=11;i++) {
    if (v) v=writeUB2(handle,str->wPlaying[i]);
  }

  for (int i=1;i<11;i++) {
    if (str->sPassword[i]=="") str->sPassword[i]="NOPASSWORD";
    for (int j=0;j<10;j++) {
      c=str->sPassword[i].GetAt(j) + pw2.GetAt(9-j) - 32;
      pw1 |=c;
    }
    fseek(handle,68+(i-1)*10,SEEK_SET);
    if (v) v=writeXString(handle,10,pw1);
    fseek(handle,68+110+(i-1)*10,SEEK_SET);
    if (v) v=writeXString(handle,10,pw2);
  }

  fseek(handle,448,SEEK_SET);
  if (v) v=writeUB2(handle,str->wLastNormalBuild);

  fclose(handle);
  return v;
}
