/*
 * Read/write planet name and coordinate data
 * part of the Host-Toolkit library
 */

#include <stdio.h>
#include "tkhost.h"
#include "tkh.h"
#include "tkiocomm.h"

PLANET_COORDS *read_planet_coords(int pnum)
{
  FILE *handle;
  PLANET_COORDS *str;

  handle=mkopen("xyplan.dat",true,'r');
  if (!handle) return NULL;

  if (pnum>NUM_PLANETS || pnum<1) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,6*(pnum-1),SEEK_SET);

  str=new PLANET_COORDS;
  if (!str) {
    fclose(handle);
    return NULL;
  }

  str->pos.x=readUB2(handle);
  str->pos.y=readUB2(handle);
  str->owner=readUB2(handle);

  fclose(handle);
  return str;
}

PLANET_COORDS *read_all_planet_coords()
{
  FILE *handle;
  PLANET_COORDS *str;
  int pnum;

  handle=mkopen("xyplan.dat",true,'r');
  if (!handle) return NULL;

  str=new PLANET_COORDS [501];
  if (!str) {
    fclose(handle);
    return NULL;
  }

  for(pnum=1;pnum<=500;pnum++) {
    str[pnum].pos.x=readUB2(handle);
    str[pnum].pos.y=readUB2(handle);
    str[pnum].owner=readUB2(handle);
  }

  fclose(handle);
  return str;
}

bool write_planet_coords(int pnum,PLANET_COORDS *str)
{
  FILE *handle;
  bool v;

  handle=mkopen("xyplan.dat",true,'w');
  if (!handle) return NULL;

  if (pnum>NUM_PLANETS || pnum<1) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,6*(pnum-1),SEEK_SET);

  v=writeUB2(handle,str->pos.x);
  if (v) v=writeUB2(handle,str->pos.y);
  if (v) v=writeUB2(handle,str->owner);

  fclose(handle);
  return v;
}

PLANET_NAME *read_planet_name(int pnum)
{
  FILE *handle;
  PLANET_NAME *str;

  handle=mkopen("planet.nm",true,'r');
  if (!handle) return NULL;

  if (pnum>NUM_PLANETS || pnum<1) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,20*(pnum-1),SEEK_SET);

  str=new PLANET_NAME;
  if (!str) {
    fclose(handle);
    return NULL;
  }

  str->sName=readXString(handle,20);

  fclose(handle);
  return str;
}

PLANET_NAME *read_all_planet_name()
{
  FILE *handle;
  PLANET_NAME *str;
  int pnum;

  handle=mkopen("planet.nm",true,'r');
  if (!handle) return NULL;

  str=new PLANET_NAME [501];
  if (!str) {
    fclose(handle);
    return NULL;
  }

  for(pnum=1;pnum<=500;pnum++) {
    str[pnum].sName=readXString(handle,20);
  }

  fclose(handle);
  return str;
}

bool write_planet_name(int pnum,PLANET_NAME *str)
{
  FILE *handle;
  bool v;

  handle=mkopen("planet.nm",true,'w');
  if (!handle) return NULL;

  if (pnum>NUM_PLANETS || pnum<1) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,20*(pnum-1),SEEK_SET);

  v=writeXString(handle,20,str->sName);

  fclose(handle);
  return str;
}
