/*
 * Read VCR data
 * part of the Player-Toolkit package
 */

#include <stdio.h>
#include "tkplayer.h"
#include "tkp.h"
#include "tkiocomm.h"

int num_vcrs()
{
  FILE *handle;
  int ns;

  handle=mkopen("vcr&p.dat",false,'r');
  if (!handle) return 0;

  ns=(int)readUB2(handle);
  fclose(handle);
  return ns;
}

VCR_DATA *read_vcr_data(int vnum)
{
  FILE *handle;
  VCR_DATA *str;
  int ns;

  handle=mkopen("vcr&p.dat",true,'r');
  if (!handle) return NULL;

  ns=readUB2(handle);
  if (vnum>ns || vnum<1) {
    fclose(handle);
    return NULL;
  }

  fseek(handle,100*(vnum-1)+2,SEEK_SET);

  str=new VCR_DATA;
  if (!str) {
    fclose(handle);
    return NULL;
  }

  str->RandomSeed=readUB4(handle);
  str->wPlanetTemp=readUB2(handle);
  str->IsPlanet=readUB2(handle);
  for (int k=1;k<3;k++) {
    str->combatant[k].wMass=readUB2(handle);
  }
  for (int k=1;k<3;k++) {
    str->combatant[k].sName=readXString(handle,20);
    str->combatant[k].wDamage=readUB2(handle);
    str->combatant[k].Crew=readUB2(handle);
    str->combatant[k].wID=readUB2(handle);
    str->combatant[k].wRace=readUB2(handle);
    str->combatant[k].wBitmap=readUB2(handle);
    str->combatant[k].wBeamTech=readUB2(handle);
    str->combatant[k].wBeams=readUB2(handle);
    str->combatant[k].wBays=readUB2(handle);
    str->combatant[k].wTorpTech=readUB2(handle);
    str->combatant[k].wTorpFighters=readUB2(handle);
    str->combatant[k].wTorps=readUB2(handle);
  }
  for (int k=1;k<3;k++) {
    str->combatant[k].wShield=readUB2(handle);
  }

  fclose(handle);
  return str;
}

VCR_DATA *read_all_vcr_data()
{
  FILE *handle;
  VCR_DATA *str;
  int vnum,vmax;

  vmax=num_vcrs();
  if (vmax==0) return NULL;

  handle=mkopen("vcr&p.dat",true,'r');
  if (!handle) return NULL;

  fseek(handle,2,SEEK_SET);

  str=new VCR_DATA [vmax+1];
  if (!str) {
    fclose(handle);
    return NULL;
  }

  for(vnum=1;vnum<=vmax;vnum++) {
    str[vnum].RandomSeed=readUB4(handle);
    str[vnum].wPlanetTemp=readUB2(handle);
    str[vnum].IsPlanet=readUB2(handle);
    for (int k=1;k<3;k++) {
      str[vnum].combatant[k].wMass=readUB2(handle);
    }
    for (int k=1;k<3;k++) {
      str[vnum].combatant[k].sName=readXString(handle,20);
      str[vnum].combatant[k].wDamage=readUB2(handle);
      str[vnum].combatant[k].Crew=readUB2(handle);
      str[vnum].combatant[k].wID=readUB2(handle);
      str[vnum].combatant[k].wRace=readUB2(handle);
      str[vnum].combatant[k].wBitmap=readUB2(handle);
      str[vnum].combatant[k].wBeamTech=readUB2(handle);
      str[vnum].combatant[k].wBeams=readUB2(handle);
      str[vnum].combatant[k].wBays=readUB2(handle);
      str[vnum].combatant[k].wTorpTech=readUB2(handle);
      str[vnum].combatant[k].wTorpFighters=readUB2(handle);
      str[vnum].combatant[k].wTorps=readUB2(handle);
    }
    for (int k=1;k<3;k++) {
      str[vnum].combatant[k].wShield=readUB2(handle);
    }
  }

  fclose(handle);
  return str;
}
